@@ -12,9 +12,9 @@ def mixin_async_manager_factory(model):
     """
 
     base_manager_cls = model.objects.__class__
-    mixin_async_manager = type(f'MixinAsync{base_manager_cls.__name__}', (AsyncManager, base_manager_cls), dict())
-
-    return mixin_async_manager
+    if not base_manager_cls.__name__.startswith('MixinAsync'):
+        mixin_async_manager = type(f'MixinAsync{base_manager_cls.__name__}', (AsyncManager, base_manager_cls), dict())
+        return mixin_async_manager
 
 
 def patch_manager(model):
@@ -26,5 +26,6 @@ def patch_manager(model):
     :rtype: None
     """
     async_manager_cls = mixin_async_manager_factory(model)
-    model.objects = async_manager_cls()
-    model.objects.model = model
+    if async_manager_cls:
+        model.objects = async_manager_cls()
+        model.objects.model = model
